==> open-xchange-core_7.4.1.orig.tar.bz2: open-xchange-core-7.4.1/com.openexchange.server/src/com/openexchange/groupware/attach/impl/FireAttachedEventAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.attach.impl;

import java.util.ArrayList;
import java.util.List;
import org.apache.commons.logging.Log;
import com.openexchange.log.LogFactory;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.attach.AttachmentExceptionCodes;
import com.openexchange.groupware.attach.AttachmentMetadata;

public class FireAttachedEventAction extends AttachmentEventAction {

    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(FireAttachedEventAction.class));

    @Override
    protected void undoAction() throws OXException {
        try {
            fireDetached(getAttachments(), getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
        } catch (final OXException e) {
            throw e;
        } catch (final Exception e) {
            throw AttachmentExceptionCodes.DETACH_FAILED.create(e);
        }
    }

    @Override
    public void perform() throws OXException {
        final List<AttachmentMetadata> processed = new ArrayList<AttachmentMetadata>();
        try {
            fireAttached(getAttachments(), processed, getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
        } catch (final Exception e) {
            LOG.error(e.getMessage(), e);
            try {
                fireDetached(processed, getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
            } catch (final Exception e1) {
                LOG.error(e.getMessage(), e);
                throw AttachmentExceptionCodes.UNDONE_FAILED.create(e1);
            }
            if (e instanceof OXException) {
                final OXException aoe = (OXException) e;
                throw aoe;
            }

            throw AttachmentExceptionCodes.ATTACH_FAILED.create(e);
        }
    }
}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.server/src/com/openexchange/groupware/attach/impl/FireAttachedEventAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.attach.impl;

import java.util.ArrayList;
import java.util.List;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.attach.AttachmentExceptionCodes;
import com.openexchange.groupware.attach.AttachmentMetadata;

public class FireAttachedEventAction extends AttachmentEventAction {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(FireAttachedEventAction.class);

    @Override
    protected void undoAction() throws OXException {
        try {
            fireDetached(getAttachments(), getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
        } catch (final OXException e) {
            throw e;
        } catch (final Exception e) {
            throw AttachmentExceptionCodes.DETACH_FAILED.create(e);
        }
    }

    @Override
    public void perform() throws OXException {
        final List<AttachmentMetadata> processed = new ArrayList<AttachmentMetadata>();
        try {
            fireAttached(getAttachments(), processed, getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
        } catch (final Exception e) {
            LOG.error("", e);
            try {
                fireDetached(processed, getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
            } catch (final Exception e1) {
                LOG.error("", e);
                throw AttachmentExceptionCodes.UNDONE_FAILED.create(e1);
            }
            if (e instanceof OXException) {
                final OXException aoe = (OXException) e;
                throw aoe;
            }

            throw AttachmentExceptionCodes.ATTACH_FAILED.create(e);
        }
    }
}
